==> tamaya-distribution-0.1-incubating-distribution-bin.zip: org/apache/tamaya/core/internal/converters/URLConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tamaya.core.internal.converters;

import org.apache.tamaya.spi.PropertyConverter;

import java.net.URL;
import java.util.Objects;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Converter, converting from String to URI, using new URL(value).
 */
public class URLConverter implements PropertyConverter<URL> {

    private Logger LOG = Logger.getLogger(getClass().getName());

    @Override
    public URL convert(String value) {
        String trimmed = Objects.requireNonNull(value).trim();
        try {
            return new URL(trimmed);
        } catch (Exception e) {
            LOG.log(Level.FINE, e, () -> "Unparseable URL: " + trimmed);
        }
        return null;
    }
}

==> tamaya-distribution-0.2-incubating-distribution-bin.zip: org/apache/tamaya/core/internal/converters/URLConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tamaya.core.internal.converters;

import org.apache.tamaya.spi.ConversionContext;
import org.apache.tamaya.spi.PropertyConverter;

import java.net.URL;
import java.util.Objects;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Converter, converting from String to URI, using new URL(value).
 */
public class URLConverter implements PropertyConverter<URL> {

    private final Logger LOG = Logger.getLogger(getClass().getName());

    @Override
    public URL convert(String value, ConversionContext context) {
        context.addSupportedFormats(getClass(),"<URL>");
        String trimmed = Objects.requireNonNull(value).trim();
        try {
            return new URL(trimmed);
        } catch (Exception e) {
            LOG.log(Level.FINE, "Unparseable URL: " + trimmed, e);
        }
        return null;
    }
}
